@@ -1,6 +1,6 @@
 import csv
 import importlib.resources
-from datetime import datetime, timedelta
+from enum import Enum
 from typing import Any, Optional
 
 import requests
@@ -8,27 +8,35 @@ import ujson
 from aiocache import cached
 from loguru import logger
 
-from tracarbon.conf import tracarbon_configuration as conf
-from tracarbon.exceptions import CloudProviderRegionIsMissing, CountryIsMissing
+from tracarbon.exceptions import (
+    CloudProviderRegionIsMissing,
+    CO2SignalAPIKeyIsMissing,
+    CountryIsMissing,
+)
 from tracarbon.hardwares import CloudProviders
 from tracarbon.locations.location import Location
 
 
+class CarbonIntensitySource(Enum):
+    FILE: str = "file"
+    CO2SignalAPI: str = "CO2SignalAPI"
+
+
 class Country(Location):
     """
     Country definition.
     """
 
-    name: str
-    co2g_kwh: float
-    co2g_kwh_source: str = "file"
+    co2signal_api_key: Optional[str] = None
+    co2g_kwh: float = 0.0
+    co2g_kwh_source: CarbonIntensitySource = CarbonIntensitySource.FILE
 
     @classmethod
-    def from_eu_file(cls, country_name_alpha_iso_2: str) -> "Country":
+    def from_eu_file(cls, country_code_alpha_iso_2: str) -> "Country":
         """
         Get the country from the file.
 
-        :param country_name_alpha_iso_2: the alpha_iso_2 name of the country
+        :param country_code_alpha_iso_2: the alpha_iso_2 name of the country
         :return:
         """
         with importlib.resources.path(
@@ -37,10 +45,10 @@ class Country(Location):
             with open(str(resource)) as json_file:
                 countries_values = ujson.load(json_file)["countries"]
                 for country in countries_values:
-                    if country_name_alpha_iso_2 == country["name"]:
+                    if country_code_alpha_iso_2 == country["name"]:
                         return cls.parse_obj(country)
         raise CountryIsMissing(
-            f"The country [{country_name_alpha_iso_2}] is not in the co2 emission file."
+            f"The country [{country_code_alpha_iso_2}] is not in the co2 emission file."
         )
 
     @classmethod
@@ -62,15 +70,14 @@ class Country(Location):
     @classmethod
     def get_location(
         cls,
-        country_name_alpha_iso_2: Optional[str] = None,
-        api_activated: bool = conf.api_activated,
+        co2signal_api_key: Optional[str] = None,
+        country_code_alpha_iso_2: Optional[str] = None,
     ) -> "Country":
         """
         Get the current location automatically: on cloud provider or a country.
-        If country_name_alpha_iso_2 is provided, the country will be configured from the local carbon emission file.
 
-        :param country_name_alpha_iso_2: the alpha iso 2 country name.
-        :param api_activated: activation of the live carbon emissions from available country's APIs.
+        :param country_code_alpha_iso_2: the alpha iso 2 country name.
+        :param co2signal_api_key: api key for fetching CO2 Signal API.
         :return: the country
         """
         # Cloud Providers
@@ -79,83 +86,50 @@ class Country(Location):
             return AWSLocation(region_name=cloud_provider.region_name)
 
         # Local
-        if country_name_alpha_iso_2:
-            return cls.from_eu_file(country_name_alpha_iso_2=country_name_alpha_iso_2)
-        country_name_alpha_iso_2 = cls.get_current_country()
-        country = cls.from_eu_file(country_name_alpha_iso_2=country_name_alpha_iso_2)
-        if api_activated:
-            if country.name == "fr":
-                country = France(co2g_kwh=country.co2g_kwh)
-        return country
+        if not country_code_alpha_iso_2:
+            country_code_alpha_iso_2 = cls.get_current_country()
+        if co2signal_api_key:
+            return cls(
+                co2signal_api_key=co2signal_api_key,
+                name=country_code_alpha_iso_2,
+                co2g_kwh_source=CarbonIntensitySource.CO2SignalAPI,
+            )
+        return cls.from_eu_file(country_code_alpha_iso_2=country_code_alpha_iso_2)
 
-    async def get_latest_co2g_kwh(self, today_date: str, hour: str) -> float:
+    @cached()  # type: ignore
+    async def get_latest_co2g_kwh(self) -> float:
         """
-        Get the latest CO2g_kwh for the Location.
+        Get the latest CO2g_kwh for the Location from https://www.co2signal.com/.
 
-        :param today_date: the date for the request
-        :param hour: the hour for the request
         :return: the latest CO2g_kwh
         """
-        return self.co2g_kwh
+        if self.co2g_kwh_source == CarbonIntensitySource.FILE:
+            return self.co2g_kwh
 
-    async def get_co2g_kwh(self) -> float:
-        """
-        Get the CO2g per kwh for the Location.
-
-        :return: the CO2g/kwh.
-        """
+        logger.info(
+            f"Request the latest carbon intensity in CO2g/kwh for your country {self.name}."
+        )
+        if not self.co2signal_api_key:
+            raise CO2SignalAPIKeyIsMissing()
+        response = await self.request(
+            url=f"https://api.co2signal.com/v1/latest?countryCode={self.name}",
+            headers={"auth-token": self.co2signal_api_key},
+        )
+        try:
+            self.co2g_kwh = float(response["data"]["carbonIntensity"])
+            logger.info(
+                f"The latest carbon intensity of your country {self.name} is: {self.co2g_kwh} CO2g/kwh."
+            )
+        except Exception:
+            logger.error(
+                f"Failed to get the latest carbon intensity of your country {self.name}, response: {response}"
+            )
         return self.co2g_kwh
 
     def __hash__(self) -> int:
         return hash(self.name)
 
 
-class France(Country):
-    """France Location."""
-
-    name: str = "fr"
-    co2g_kwh_source: str = "API"
-
-    @cached()  # type: ignore
-    async def get_latest_co2g_kwh(self, today_date: str, hour: str) -> float:
-        """
-        Get the latest CO2g_kwh for France.
-
-        :param today_date: the date for the request
-        :param hour: the hour for the request
-        :return: the latest CO2g_kwh
-        """
-        logger.info(
-            f"Request the current emission factor in CO2g/kwh of France at the time of {today_date} {hour}."
-        )
-        response = await self.request(
-            f"https://opendata.reseaux-energies.fr/api/records/1.0/search/?dataset=eco2mix-national-tr&q=&rows=1&facet=taux_co2&facet=date_heure&refine.date={today_date}&refine.heure={hour}"
-        )
-        try:
-            self.co2g_kwh = float(response["records"][0]["fields"]["taux_co2"])
-            logger.info(
-                f"The emission factor in CO2g/kwh of France is: {self.co2g_kwh} g/kwh."
-            )
-        except Exception:
-            logger.error(
-                "Failed to get the latest update of the CO2g/kwh update of France."
-            )
-        return self.co2g_kwh
-
-    async def get_co2g_kwh(self) -> float:
-        """
-        Get the latest co2/kwh update from the French's website https://www.rte-france.com/eco2mix.
-
-        :return: the last known CO2g/kwh value
-        """
-        now = datetime.now()
-        today_date = now.strftime("%Y-%m-%d")
-        previous_quarter = now - timedelta(minutes=61)
-        last_quarter_minute = 15 * (previous_quarter.minute // 15)
-        hour = previous_quarter.replace(minute=last_quarter_minute).strftime("%H:%M")
-        return await self.get_latest_co2g_kwh(today_date=today_date, hour=hour)
-
-
 class AWSLocation(Country):
     """
     AWS Location.
